@@ -10,6 +10,7 @@ link_targets[2] = [
  ["(mod-path._.'compiler/find-exe.')", "../raco/exe.html#%28mod-path._compiler%2Ffind-exe%29"],
  ["(mod-path._.'compiler/module-suffix.')", "../raco/API_for_Raw_Compilation.html#%28mod-path._compiler%2Fmodule-suffix%29"],
  ["(mod-path._.'contract-profile.')", "../contract-profile/index.html"],
+ ["(mod-path._.'db/util/cassandra.')", "../db/util.html#%28mod-path._db%2Futil%2Fcassandra%29"],
  ["(mod-path._.'drscheme/tool-lib.')", "../tools/index.html"],
  ["(mod-path._.'dynext/compile.')", "../dynext/Compilation.html"],
  ["(mod-path._.'dynext/file-unit.')", "../dynext/Filenames.html#%28mod-path._dynext%2Ffile-unit%29"],
@@ -192,6 +193,7 @@ link_targets[2] = [
  ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'.D.B2_.O.D.B.C_.Driver.'))", "../db/notes.html#%28part._.D.B2_.O.D.B.C_.Driver%29"],
  ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'.S.Q.L_.N.U.L.L.'))", "../db/sql-types.html#%28part._.S.Q.L_.N.U.L.L%29"],
  ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'.S.Q.L_.Server_.O.D.B.C_.Driver.'))", "../db/notes.html#%28part._.S.Q.L_.Server_.O.D.B.C_.Driver%29"],
+ ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'cassandra-types.'))", "../db/sql-types.html#%28part._cassandra-types%29"],
  ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'datetime-util.'))", "../db/util.html#%28part._datetime-util%29"],
  ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'dbperf-n+1.'))", "../db/using-db.html#%28part._dbperf-n%2B1%29"],
  ["(part._(.'(lib._db/scribblings/db..scrbl).'._.'dbperf-testing.'))", "../db/using-db.html#%28part._dbperf-testing%29"],
@@ -383,7 +385,6 @@ link_targets[2] = [
  ["(part._(.'(lib._redex/redex..scrbl).'._.'.Defining_a_.Reduction_.Relation.'))", "../redex/tutorial.html#%28part._.Defining_a_.Reduction_.Relation%29"],
  ["(part._(.'(lib._redex/redex..scrbl).'._.'.Developing_a_.Language_2.'))", "../redex/redex2015.html#%28part._.Developing_a_.Language_2%29"],
  ["(part._(.'(lib._redex/redex..scrbl).'._.'.Languages.'))", "../redex/The_Redex_Reference.html#%28part._.Languages%29"],
- ["(part._(.'(lib._redex/redex..scrbl).'._.'.Objects__.Problem.'))", "../redex/Objects__Problem.html"],
  ["(part._(.'(lib._redex/redex..scrbl).'._.'.Problem__.G.C.'))", "../redex/Problem__GC.html"],
  ["(part._(.'(lib._redex/redex..scrbl).'._.'.Problem__.Missionaries_and_.Cannibals.'))", "../redex/Problem__Missionaries_and_Cannibals.html"],
  ["(part._(.'(lib._redex/redex..scrbl).'._.'.Redex__.Practical_.Semantics_.Engineering.'))", "../redex/index.html"],
@@ -744,7 +745,6 @@ link_targets[2] = [
  ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Experimental_.Features.'))", "../ts-reference/Experimental_Features.html"],
  ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Exploring_.Types.'))", "../ts-reference/Exploring_Types.html"],
  ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Libraries_.Provided_.With_.Typed_.Racket.'))", "../ts-reference/Libraries_Provided_With_Typed_Racket.html"],
- ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Refinements_and_.Linear_.Integer_.Reasoning.'))", "../ts-reference/Experimental_Features.html#%28part._.Refinements_and_.Linear_.Integer_.Reasoning%29"],
  ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Signature_.Forms.'))", "../ts-reference/Typed_Units.html#%28part._.Signature_.Forms%29"],
  ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Signatures_and_.Internal_.Definition_.Contexts.'))", "../ts-reference/Typed_Units.html#%28part._.Signatures_and_.Internal_.Definition_.Contexts%29"],
  ["(part._(.'(lib._typed-racket/scribblings/ts-reference..scrbl).'._.'.Syntax_.Objects.'))", "../ts-reference/type-ref.html#%28part._.Syntax_.Objects%29"],
